Stan Math Library: stan::VectorBuilder< used, T1, T2, T3, T4, T5, T6, T7 > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
stan::VectorBuilder< used, T1, T2, T3, T4, T5, T6, T7 > Class Template Reference

VectorBuilder allocates type T1 values to be used as intermediate values. More...

`#include <VectorBuilder.hpp>`

## Public Member Functions
| VectorBuilder (size_t n)
T1 & | operator[] (size_t i)
VectorBuilderHelper< T1, used, contains_vector< T2, T3, T4, T5, T6, T7 >::value >::type | data ()

## Public Attributes
VectorBuilderHelper< T1, used, contains_vector< T2, T3, T4, T5, T6, T7 >::value > | a

## Detailed Description

### template<bool used, typename T1, typename T2, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double, typename T7 = double>
class stan::VectorBuilder< used, T1, T2, T3, T4, T5, T6, T7 >

VectorBuilder allocates type T1 values to be used as intermediate values.

There are 2 template parameters:

- used: boolean variable indicating whether this instance is used. If this is false, there is no storage allocated and operator[] throws.
- is_vec: boolean variable indicating whether this instance should allocate a vector, if it is used. If this is false, the instance will only allocate a single double value. If this is true, it will allocate the number requested. Note that this is calculated based on template parameters T2 through T7.

These values are mutable.

Definition at line 28 of file VectorBuilder.hpp.

## Constructor & Destructor Documentation

template<bool used, typename T1, typename T2, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double, typename T7 = double>

stan::VectorBuilder< used, T1, T2, T3, T4, T5, T6, T7 >::VectorBuilder | ( | size_t | n | ) |
| inlineexplicit

Definition at line 33 of file VectorBuilder.hpp.

## Member Function Documentation

template<bool used, typename T1, typename T2, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double, typename T7 = double>

VectorBuilderHelper<T1, used, contains_vector<T2, T3, T4, T5, T6, T7>::value>::type stan::VectorBuilder< used, T1, T2, T3, T4, T5, T6, T7 >::data | ( |  | ) |
| inline

Definition at line 42 of file VectorBuilder.hpp.

template<bool used, typename T1, typename T2, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double, typename T7 = double>

T1& stan::VectorBuilder< used, T1, T2, T3, T4, T5, T6, T7 >::operator[] | ( | size_t | i | ) |
| inline

Definition at line 35 of file VectorBuilder.hpp.

## Member Data Documentation

template<bool used, typename T1, typename T2, typename T3 = double, typename T4 = double, typename T5 = double, typename T6 = double, typename T7 = double>

VectorBuilderHelper<T1, used, contains_vector<T2, T3, T4, T5, T6, T7>::value> stan::VectorBuilder< used, T1, T2, T3, T4, T5, T6, T7 >::a

Definition at line 31 of file VectorBuilder.hpp.

The documentation for this class was generated from the following file:

- stan/math/prim/scal/meta/VectorBuilder.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.